@@ -11,7 +11,8 @@ class UraniumRequirementSet(RequirementSet):
     uranium_versions = {}
 
     def add_requirement(self, install_req):
-        self._uranium_rectify_versions(install_req)
+        if not install_req.editable:
+            self._uranium_rectify_versions(install_req)
         super(RequirementSet, self).add_requirement(install_req)
 
     def _uranium_rectify_versions(self, install_req):
@@ -21,4 +22,4 @@ class UraniumRequirementSet(RequirementSet):
             new_spec = self.uranium_versions[name]
             # new_spec is a string, but it works
             # because the & operator accepts string
-            install_req.specifier = old_specifier & new_spec
+            install_req.req.specifier = old_specifier & new_spec
